==> haskell-lambdabot-trusted-5.3.1.2-188-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lambdabot-trusted.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lambdabot-trusted
version:              5.3.1.2
visibility:           public
id:                   lambdabot-trusted-5.3.1.2-5eO5DcRN11HFxpNY1VIYOR
key:                  lambdabot-trusted-5.3.1.2-5eO5DcRN11HFxpNY1VIYOR
license:              LicenseRef-GPL
maintainer:           Naïm Favier <n@monade.li>
author:               Bertram Felgenhauer
homepage:             https://wiki.haskell.org/Lambdabot
synopsis:             Lambdabot trusted code.
description:
    Lambdabot is an IRC bot written over several years by
    those on the #haskell IRC channel.

    This small package provides functions used by
    the \@run command.

category:             Development, Web
abi:                  18701f0b9842f1eb7f32ba0feb06daf3
exposed:              True
exposed-modules:      Lambdabot.Plugin.Haskell.Eval.Trusted
hidden-modules:       Lambdabot.Plugin.Haskell.Check.ShowQ
import-dirs:          /usr/lib/ghc-9.4.8/site-local/lambdabot-trusted-5.3.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lambdabot-trusted-5.3.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lambdabot-trusted-5.3.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lambdabot-trusted
hs-libraries:         HSlambdabot-trusted-5.3.1.2-5eO5DcRN11HFxpNY1VIYOR
depends:
    QuickCheck-2.14.3-8uOdgqaEmIi7siaoGpKSGc
    QuickCheck-safe-0.1.0.6-7SGuvzDNqzLGrxGHkrABA9 base-4.17.2.1
    oeis-0.3.10.1-ETZtSZsixXY3kWTXpddiyY

haddock-interfaces:
    /usr/share/doc/haskell-lambdabot-trusted/html/lambdabot-trusted.haddock

haddock-html:         /usr/share/doc/haskell-lambdabot-trusted/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lambdabot-trusted-5.3.1.2-189-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lambdabot-trusted.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lambdabot-trusted
version:              5.3.1.2
visibility:           public
id:                   lambdabot-trusted-5.3.1.2-I7EtcDVz16z7IOp5P8jXvJ
key:                  lambdabot-trusted-5.3.1.2-I7EtcDVz16z7IOp5P8jXvJ
license:              LicenseRef-GPL
maintainer:           Naïm Favier <n@monade.li>
author:               Bertram Felgenhauer
homepage:             https://wiki.haskell.org/Lambdabot
synopsis:             Lambdabot trusted code.
description:
    Lambdabot is an IRC bot written over several years by
    those on the #haskell IRC channel.

    This small package provides functions used by
    the \@run command.

category:             Development, Web
abi:                  1b412094b5838c8da2519e67bc809ed1
exposed:              True
exposed-modules:      Lambdabot.Plugin.Haskell.Eval.Trusted
hidden-modules:       Lambdabot.Plugin.Haskell.Check.ShowQ
import-dirs:          /usr/lib/ghc-9.4.8/site-local/lambdabot-trusted-5.3.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lambdabot-trusted-5.3.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lambdabot-trusted-5.3.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lambdabot-trusted
hs-libraries:         HSlambdabot-trusted-5.3.1.2-I7EtcDVz16z7IOp5P8jXvJ
depends:
    QuickCheck-2.14.3-8uOdgqaEmIi7siaoGpKSGc
    QuickCheck-safe-0.1.0.6-7SGuvzDNqzLGrxGHkrABA9 base-4.17.2.1
    oeis-0.3.10.1-4PTENodRW1DJ1mqVqxfqEy

haddock-interfaces:
    /usr/share/doc/haskell-lambdabot-trusted/html/lambdabot-trusted.haddock

haddock-html:         /usr/share/doc/haskell-lambdabot-trusted/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
